import { ITheme, IThemeDTO, Theme, ThemeVisibility } from "./theme";
/**
 * @interface IUserThemeDTO
 * @description
 *      Data Transfer Object (DTO) for transferring required data that represents a Theme that is available for a user.
 */
export interface IUserThemeDTO extends IThemeDTO {
    isThemeSelectedByUser: boolean;
    isThemeSelectedByAdmin: boolean;
}
/**
 * @interface IUserTheme
 * @description
 *      Interface that represents a theme that is available for a user.
 */
export interface IUserTheme extends ITheme, Omit<IUserThemeDTO, "UIElements"> {
}
/**
 * @class
 * @name UserTheme
 * @description
 *      This class is used to represent a Theme that is available for a user.
 */
export declare class UserTheme extends Theme implements Required<IUserTheme> {
    /**
     * @public
     * @property {boolean} isThemeSelectedByUser This boolean informs if the user has already selected this theme (only present for a theme that is available for a specified user).
     * @readonly
     */
    isThemeSelectedByUser: boolean;
    /**
     * @public
     * @property {boolean} isThemeSelectedByAdmin This boolean informs if the admin has already selected this theme for the user (only present for a theme that is available for a specified user).
     * @readonly
     */
    isThemeSelectedByAdmin: boolean;
    constructor(data: Partial<IUserTheme | ITheme>);
    static createFromData(data: IUserThemeDTO | IThemeDTO): UserTheme;
    static create(id: string, name: string, displayName: string, visibility: ThemeVisibility): UserTheme;
}
//# sourceMappingURL=userTheme.d.ts.map