/**
 * @module
 * @public
 * @name CompanyDirectoryContact
 * @description
 * This class is used to represent an entry in the collective directory of a company
 */
export declare class DirectoryContact {
    /**
     * @public
     * @property {string} id - Directory entry identifier
     *
     */
    id: string;
    /**
     * @public
     * @name directoryType
     * @enum {string} Defines the type of directory contact: "company" or "personal"
     * @readonly
     */
    directoryType: string;
    /**
     * @public
     * @property {string} companyId - Id of the company (only for entries from "company" directory type)
     *
     */
    companyId: string;
    /**
     * @public
     * @property {string} userId - Id of the user owner of the contact (only for entries from "personal" directory type)
     *
     */
    userId: string;
    /**
     * @public
     * @property {string} firstName - First name of the contact
     *
     */
    firstName: string;
    /**
     * @public
     * @property {string} lastName - Last name of the contact
     *
     */
    lastName: string;
    /**
     * @public
     * @property {string} eMail - Email address of the contact
     *
     */
    eMail: string;
    /**
     * @public
     * @property {string} jobTitle - Job title
     *
     */
    jobTitle: string;
    /**
     * @public
     * @property {string} department - Department
     *
     */
    department: string;
    /**
     * @public
     * @property {string} companyName - Name of the company
     *
     */
    companyName: string;
    /**
     * @public
     * @property {string} street - Contact address : Street
     *
     */
    street: string;
    /**
     * @public
     * @property {string} city - Contact address : City
     *
     */
    city: string;
    /**
     * @public
     * @property {string} state - Contact address : State (only when country is 'USA' or 'CAN')
     *
     */
    state: string;
    /**
     * @public
     * @property {string} postalCode - Contact address : Postal code / ZIP
     *
     */
    postalCode: string;
    /**
     * @public
     * @property {string} country - Contact address : Country
     *
     */
    country: string;
    /**
     * @public
     * @property {Array<string>} workPhoneNumbers - Work phone numbers (E164 format! e.g: ["+33390671234"])
     *
     */
    workPhoneNumbers: string[];
    /**
     * @public
     * @property {Array<string>} mobilePhoneNumbers - Mobile phone numbers (E164 format! e.g: ["+33690671234", "+33 6 90 67 67 91"])
     *
     */
    mobilePhoneNumbers: string[];
    /**
     * @public
     * @property {Array<string>} otherPhoneNumbers - Other phone numbers (E164 format! e.g: ["+33690671234", "+33 6 90 67 67 91"])
     *
     */
    otherPhoneNumbers: string[];
    /**
     * @public
     * @property {string} custom1 - Custom field
     *
     */
    custom1: string;
    /**
     * @public
     * @property {string} custom2 - Other custom field
     *
     */
    custom2: string;
    /**
     * @public
     * @property {string} tags - contact tags
     *
     */
    tags: string[];
    /**
     * @public
     * @property {object[]} aliases - Aliases of the directory entry
     *
     */
    aliases: {
        type: string;
        code: string;
    }[];
    /**
     * @public
     * @param {object} data The object containing the attributes of the company directory contact
     * @returns {DirectoryContact} the created company directory contact
     */
    static createFromData(data: any): DirectoryContact;
    constructor(directoryType?: string, companyId?: string, userId?: string, id?: string, firstName?: string, lastName?: string, eMail?: string, jobTitle?: string, department?: string, companyName?: string, street?: string, city?: string, state?: string, postalCode?: string, country?: string, workPhoneNumbers?: string[], mobilePhoneNumbers?: string[], otherPhoneNumbers?: string[], custom1?: string, custom2?: string, tags?: string[], aliases?: {
        type: string;
        code: string;
    }[]);
    toJSON(): {
        companyId: string;
        id: string;
        firstName: string;
        lastName: string;
        eMail: string;
        jobTitle: string;
        department: string;
        companyName: string;
        street: string;
        city: string;
        state: string;
        postalCode: string;
        country: string;
        workPhoneNumbers: string[];
        mobilePhoneNumbers: string[];
        otherPhoneNumbers: string[];
        custom1: string;
        custom2: string;
        tags: string[];
        aliases: {
            type: string;
            code: string;
        }[];
    } | {
        id: string;
        firstName: string;
        lastName: string;
        eMail: string;
        jobTitle: string;
        department: string;
        companyName: string;
        street: string;
        city: string;
        state: string;
        postalCode: string;
        country: string;
        workPhoneNumbers: string[];
        mobilePhoneNumbers: string[];
        otherPhoneNumbers: string[];
        custom1: string;
        custom2: string;
        tags: string[];
        aliases: {
            type: string;
            code: string;
        }[];
        companyId?: undefined;
    };
}
//# sourceMappingURL=directoryContact.model.d.ts.map