import { User } from './user.model';
/**
 * This class is used to represent an invitation received or sent by/to user <br/>
 */
export declare class NetworkInvitation {
    static create(id: string, invitedUserId: string, invitedUserEmail: string, invitingUserId: string, invitingUserEmail: string, requestNotificationLanguage: string, invitingDate: string, lastNotificationDate: string, status: string, type: string, inviteToJoinMeeting: string): NetworkInvitation;
    static createFromData(invitationData: any): NetworkInvitation;
    /**
     * The invitation ID
     * @readonly
     */
    id: string;
    /**
     * The invited user
     * @readonly
     */
    invitedUser?: User;
    /**
     * The invited user Rainbow id
     * @readonly
     */
    invitedUserId: string;
    /**
     * The invited user email
     * @readonly
    */
    invitedUserEmail: string;
    /**
     * The invited phone number
     * @readonly
     */
    invitedPhoneNumber: string;
    /**
     * The inviting user
     * @readonly
     */
    invitingUser?: User;
    /**
     * The inviting user identifier
     * @readonly
     */
    invitingUserId: string;
    /**
     * The inviting user email adress
     * @readonly
     */
    invitingUserEmail: string;
    /**
     * The request notification language
     * @readonly
     */
    requestNotificationLanguage: string;
    /**
     * The date the invitation was created
     * @readonly
     */
    invitingDate: string;
    /**
     * The date when the last email notification was sent.
     * @readonly
     */
    lastNotificationDate: string;
    /**
     * The invitation status
     * @readonly
     */
    status: string;
    /**
     * The invitation type
     * @readonly
     */
    type: string;
    /**
     * True if joinRoom invitation.
     * @readonly
     */
    inviteToJoinMeeting: string;
    /**
     * The invitation default avatar
     * @readonly
     */
    defaultAvatar: any;
    /** @internal */
    constructor(id: string, invitedUserId: string, invitedUserEmail: string, invitingUserId: string, invitingUserEmail: string, requestNotificationLanguage: string, invitingDate: string, lastNotificationDate: string, status: string, type: string, inviteToJoinMeeting: any, invitedPhoneNumber?: string);
    createDefaultAvatar(): void;
    toJSON(): any;
}
//# sourceMappingURL=invitation.model.d.ts.map