/**
 * @class
 * @name TelephonyForward
 * @description
 *	  This class represents a telephony forward.
 */
export declare class TelephonyForward {
    /**
     * @public
     * @property {string} type The forward type.
     *           Supported values: "immediate", "busy", "noreply"
     * @readonly
     */
    type: string;
    /**
     * @public
     * @property {boolean} activate True if the corresponding forward for this type is activated
     */
    activate: boolean;
    /**
     * @public
     * @property {string} destinationType The destination type of the forward (sipWise only).
     *           Supported values: "voicemail", "internalnumber", "externalnumber"
     */
    destinationType?: string;
    /**
     * @public
     * @property {string} name The name of the forward destination (user or group's displayname)
     */
    name?: string;
    /**
     * @public
     * @property {string} number The phone number of the forward destination
     */
    number?: string;
    /**
     * @public
     * @property {string} userId The user identifier of the forward destination (if the destination is a user)
     */
    userId?: string;
    constructor(type: string, activate: boolean, destinationType?: string, name?: string, number?: string, userId?: string);
    static createForwardFromVoiceUserData(data: any): TelephonyForward;
    static createForwardFromHybridData(hybridForwardData: {
        forwardType: string;
        pbxForwardType: string;
        forwardTo: string;
    }): TelephonyForward;
    updateFromVoiceEventData(activate: boolean, destinationType: string, name: string): this;
}
//# sourceMappingURL=telephonyForward.model.d.ts.map