/**
 * @module Admin
 */
import { Company } from '../../models/company.model';
import { Service } from '../../services/service';
import { Contact } from '../../models/contact.model';
/** @internal */
export declare const SDK_ADMIN_SVC = "SDKAdminService";
export interface SDKAdminService {
    /**
     * Get all companies
     */
    getCompanies(): Promise<Company[]>;
    /**
     * Create a company
     * @param name - Company name
     * @param country - String representing company's country
     * @param state - String representing company's state
     */
    createCompany(name: string, country: string, state?: string): Promise<Company>;
    /**
     * Remove a company by passing its ID
     * @param companyRef - CompanyRef Id or Company Object
     */
    removeCompany(companyRef: string | Company): Promise<void>;
    /**
     * Get users for a given company
     * @param companyRef - ID of Company or the Company instance for which the user is supposed to be created
     */
    getUsersForCompany(companyRef: string | Company): Promise<Contact[]>;
    /**
     * Create a new user for a given company
     * @param login - User login
     * @param firstName - User first name
     * @param lastName - User last name
     * @param password - User password
     * @param companyRef - ID of Company or the Company instance for which the user is supposed to be created
     * @param tags -Array of tags for the user (optional)
     */
    createUserForCompany(login: string, firstName: string, lastName: string, password: string, companyRef: string | Company, tags: string[]): Promise<any>;
    /**
     * Remove a user from its company
     * @param  userId - User identifier
     */
    removeUser(userId: string): Promise<void>;
}
/**
 * @internal
 */
export declare class SDKAdminServiceRB extends Service implements SDKAdminService {
    private authService;
    private contactService;
    private loggerService;
    private errorHelperService;
    static getInstance(): SDKAdminServiceRB;
    static build(): SDKAdminServiceRB;
    protected constructor();
    getCompanies(): Promise<Company[]>;
    createCompany(name: string, country: string, state?: string): Promise<Company>;
    removeCompany(companyRef: string | Company): Promise<void>;
    getUsersForCompany(companyRef: string | Company, detailsLevel?: string, filters?: any[]): Promise<any[]>;
    createUserForCompany(login: string, firstName: string, lastName: string, password: string, companyRef: string | Company, tags?: string[]): Promise<any>;
    removeUser(userId: string): Promise<void>;
    updateUser(user: any): Promise<void>;
    getServerVersion(): Promise<string>;
    private getCompanyId;
}
//# sourceMappingURL=admin.service.d.ts.map