import { CallRB } from "../../models/call.model";
import { Service } from '../../services/service';
import { Subscription } from 'rxjs';
import { FileDescriptor } from '../../models/common';
/** @internal */
export declare const CALL_RECORDER_SERVICE = "CallRecorderService";
/**
 * @internal
 * This RecorderState enum lists all the states a record can be in.
*/
export declare enum RecorderState {
    /**
     * This 'RECORDING_IN_PROGRESS' state means that the recording is in progress.
    */
    RECORDING_IN_PROGRESS = "RECORDING_IN_PROGRESS",
    /**
     * This 'RECORDING_PAUSED' state means that the recording is on pause.
    */
    RECORDING_PAUSED = "RECORDING_PAUSED",
    /**
     * This 'RECORDING_STOPPED' state means that the recording is stopped.
    */
    RECORDING_STOPPED = "RECORDING_STOPPED"
}
export interface CallRecorderInstance {
    id: string;
    mediaRecorder?: MediaRecorder;
    audioContext: AudioContext;
    subscriptions?: Subscription[];
    data?: Blob;
    duration?: number;
    durationTimer?: Subscription;
    fileName?: string;
    recordFile?: any;
    backupFileDescriptor?: FileDescriptor;
    fullPathUrl?: string;
    inputPeerConnection?: RTCPeerConnection;
    ouputPeerConnection?: RTCPeerConnection;
    outputVideoStream?: any;
}
/**
 * The CallRecorderService class contains the methods and their implementations required for recording.
*/
export declare class CallRecorderService extends Service {
    private conversationService;
    private innerRxSubject;
    private rxSubject;
    private xmppService;
    private fileStorageService;
    private eventService;
    private fileServerService;
    private errorHelperService;
    private logger;
    private i18n;
    private mainService;
    private contactService;
    private webrtcP2PServce;
    private centralizedService;
    private recorders;
    private blankVideoTrack;
    private blankVideoTrackInterval;
    private blankVideoStream;
    private videoElement;
    private canvasElement;
    static getInstance(): CallRecorderService;
    static build(): CallRecorderService;
    protected constructor();
    start(): Promise<void>;
    stop(): Promise<void>;
    startRecording(call: CallRB): Promise<void>;
    private buildLocalPeerConnection;
    stopRecording(call: CallRB): Promise<void>;
    pauseRecording(call: CallRB): void;
    resumeRecording(call: CallRB): void;
    getRecordingDuration(call: any): number;
    private addListenersForCall;
    /**
     * This method creates a file from blob for the Safari web browser.
     * @param blob - The blob used to create the file.
    */
    private onCreateFileFromBlobForSafari;
    private getOrCreateVideoTrack;
    private createBlackTrack;
    /**
     * This method uploads a back-up file to the local Rainbow storage.
    */
    uploadFileToServer(recordingInstance: CallRecorderInstance, backup?: boolean): Promise<any>;
    /**
     * This method is called when data are available in MediaRecorder.
     *  @param event - The event received.
    */
    onDataAvailable(event: any, recorderInstance: CallRecorderInstance): Promise<any>;
    /**
     * @private
     * This method creates blob from data.
    */
    private onStop;
    private writeFileToDisk;
    /**
     * This method creates a file from blob for any web browser.
    */
    private createFinalFileForRecording;
    private removeRecordingInstance;
    /**
     * Try to repair the file by injecting missing data; This should be done via FFMPEG but keep it like this for the moment
     * @param blob - The blob used to create the file.
    */
    private injectMetadata;
    private closeAudioContext;
    private onError;
}
//# sourceMappingURL=callRecorder.service.d.ts.map