import { Service } from '../../services/service';
export declare const COUNTRY_SVC = "CountryService";
export interface Country {
    name: string;
    "alpha-2": string;
    "alpha-3": string;
    "country-code"?: string;
    default?: boolean;
}
export declare class CountryService extends Service {
    private portalURL;
    private errorHelperService;
    private authService;
    private logger;
    private i18n;
    /**
     * List of data center locations, grouped by geographical regions
     */
    datacenters: any[];
    /**
     * List of countries (obsolete)
     */
    countries: Country[];
    /** Alphabetical list of Canadian states **/
    statesOfCanada: any;
    /** Alphabetical list of US states **/
    statesOfAmerica: any;
    countryToInternationalCallingCodeMapping: any;
    countryToLanguageMapping: any;
    private timeZoneCityToCountry;
    static getInstance(): CountryService;
    static build(): CountryService;
    private constructor();
    start(): Promise<void>;
    stop(): Promise<void>;
    /********************************************************/
    /** PUBLIC                                             **/
    /********************************************************/
    getCountries(): Country[];
    getCountryStates(country: any): any;
    getCountry(countryCodeAlpha3: string, defaulted?: any): Country;
    getCountryFromAlpha2(countryCodeAlpha2: string): Country;
    getDefaultCountry(): Country;
    getCountryName(countryCode: string): string;
    getCountryCode(country: Country): string;
    getCountryDataFromName(countryName: string): Country;
    getCountryCodeFromName(countryName: string): string;
    getStateCodeFromName(countryName: string, stateName: string): string;
    getStateName(country: string, state: string): string;
    getDefaultState(country: any): string;
    getAlpha2Code(alpha3Code: string): string;
    getAlpha3Code(alpha2Code: string): string;
    getCountryLabel(alphaCode: string): string;
    getDataCenterLabel(datacenterLocation: any, companyCountry: any): string;
    getRegionLabel(regionName: string): string;
    getInternationalCallingCode(countryAlpha2Code: string): string;
    mapCountryToLanguages(countryAlpha2Code: string): string[];
    initializeCountriesWithoutAuthToken(): Promise<void>;
    /********************************************************/
    /** PRIVATE                                            **/
    /********************************************************/
    private initializeCountries;
    private getAvailableCountries;
    getCountryFromComputerTimezone(): Country;
}
//# sourceMappingURL=country.service.d.ts.map