import { Service } from '../../services/service';
/**
 * @internal
 */
export declare const LOGGER_SVC = "LoggerService";
interface ExternalLoggerInterface {
    error: (message: string, ...args: unknown[]) => void;
    warn: (message: string, ...args: unknown[]) => void;
    info: (message: string, ...args: unknown[]) => void;
    infoBlue: (message: string, ...args: unknown[]) => void;
    infoEvent: (message: string, ...args: unknown[]) => void;
    infoUser: (message: string, ...args: unknown[]) => void;
    infoOrange: (message: string, ...args: unknown[]) => void;
    log: (message: string, ...args: unknown[]) => void;
    debug: (message: string, ...args: unknown[]) => void;
    webrtc: (message: string, ...args: unknown[]) => void;
    sdk: (message: string, ...args: unknown[]) => void;
    sdkError: (message: string, ...args: unknown[]) => void;
}
declare enum LogLevelColor {
    trace = "color:blue",
    debug = "color:gray",
    info = "color:teal",
    infoUser = "color:darkslateblue",
    infoEvent = "color:darkslategrey",
    infoBlue = "color:white; background: blue",
    infoRed = "color:white; background: red",
    infoOrange = "color:black; background: orange",
    log = "color:teal",
    warn = "color:red",
    error = "color:red",
    webrtc = "color:green"
}
export declare enum LogLevelEnum {
    ERROR = 0,
    WARNING = 1,
    INFO = 2,
    DEBUG = 3
}
type LogLevel = keyof typeof LogLevelColor;
export declare class LoggerService extends Service implements ExternalLoggerInterface {
    /**
    * @internal
    */
    enableConsoleLog: boolean;
    logLevel: LogLevelEnum;
    logsBufferSize: number;
    private logsBuffer;
    private desktopMode;
    private externalLogger?;
    private settingsService;
    /**
     * @internal
     */
    static getInstance(): LoggerService;
    /**
     * @internal
     */
    static build(): LoggerService;
    private constructor();
    /**
     * @internal
     */
    computeConsoleStatus(): void;
    /**
     * @internal
     */
    configure<T extends ExternalLoggerInterface>(externalLogger: T): void;
    static makeObscure(str: string): string;
    error(message: string, ...args: unknown[]): void;
    warn(message: string, ...args: unknown[]): void;
    info(message: string, ...args: unknown[]): void;
    log(message: string, ...args: unknown[]): void;
    debug(message: string, ...args: unknown[]): void;
    /**
     * @internal
     */
    infoEvent(message: string, ...args: unknown[]): void;
    /**
     * @internal
     */
    infoUser(message: string, ...args: unknown[]): void;
    /**
     * @internal
     */
    infoBlue(message: string, ...args: unknown[]): void;
    /**
     * @internal
     */
    infoOrange(message: string, ...args: unknown[]): void;
    /**
     * @internal
     */
    infoRed(message: string, ...args: unknown[]): void;
    /**
     * @internal
     */
    webrtc(message: string, ...args: unknown[]): void;
    /**
     * @internal
     */
    sdk(message: string, ...args: unknown[]): void;
    /**
     * @internal
     */
    sdkError(message: string, ...args: unknown[]): void;
    /**
     * @internal
     */
    getLogs(): string[];
    /**
     * @internal
     */
    logger(level: LogLevel, text: string, ...args: unknown[]): void;
    private getRealLevel;
    private getLogLevelEnum;
}
export {};
//# sourceMappingURL=logger.service.d.ts.map