import { BehaviorSubject, Subject, Subscription } from 'rxjs';
import { Service } from '../../services/service';
export declare const PROFILE_SVC = "ProfileService";
/**
 * Description: Some bot or process needs a permanent authentication even though the account authentication changes.
 * Managing the full JWT authentication process is not relevant on low power devices (iOT,...).
 * In those cases, we can use API_KEYS instead;
 * This is the Interface of the SDK API Key
 */
export interface SdkApiKey {
    apiKey?: string;
    id?: string;
    scope: string[];
    description: string;
    isActive: boolean;
    userId?: string;
    loginEmail?: string;
    expirationDate: string;
}
export declare enum ProfileFeatures {
    COMPANY_ADMIN_COUNT = "COMPANY_ADMIN_COUNT",
    COMPANY_LOGO_MODIFICATION = "COMPANY_LOGO_MODIFICATION",
    COMPANY_DOMAIN_NAME_MODIFICATION = "COMPANY_DOMAIN_NAME_MODIFICATION",
    COMPANY_DETAILS_MODIFICATION = "COMPANY_DETAILS_MODIFICATION",
    COMPANY_SINGLE_SIGN_ON_SAML = "COMPANY_SINGLE_SIGN_ON_SAML",
    COMPANY_SINGLE_SIGN_ON_OIDC = "COMPANY_SINGLE_SIGN_ON_OIDC",
    SECURITY_MFA_TOTP = "SECURITY_MFA_TOTP",
    WEBRTC_FOR_MOBILE = "WEBRTC_FOR_MOBILE",
    BUBBLE_PARTICIPANT_COUNT = "BUBBLE_PARTICIPANT_COUNT",
    TELEPHONY_BASIC_CALL = "TELEPHONY_BASIC_CALL",
    TELEPHONY_SECOND_CALL = "TELEPHONY_SECOND_CALL",
    TELEPHONY_TRANSFER_CALL = "TELEPHONY_TRANSFER_CALL",
    TELEPHONY_CONFERENCE_CALL = "TELEPHONY_CONFERENCE_CALL",
    TELEPHONY_DEFLECT_CALL = "TELEPHONY_DEFLECT_CALL",
    TELEPHONY_PHONE_BOOK = "TELEPHONY_PHONE_BOOK",
    TELEPHONY_VOICE_MAIL = "TELEPHONY_VOICE_MAIL",
    TELEPHONY_CALL_FORWARD = "TELEPHONY_CALL_FORWARD",
    TELEPHONY_NOMADIC = "TELEPHONY_NOMADIC",
    CONFERENCE_PARTICIPANT_COUNT = "CONFERENCE_PARTICIPANT_COUNT",
    WEBRTC_CONFERENCE_ALLOWED = "WEBRTC_CONFERENCE_ALLOWED",
    WEBRTC_CONFERENCE_PARTICIPANT_COUNT = "WEBRTC_CONFERENCE_PARTICIPANT_COUNT",
    WEBRTC_PARTICIPANT_ALLOWED = "WEBRTC_PARTICIPANT_ALLOWED",
    CONFERENCE_ALLOWED = "CONFERENCE_ALLOWED",
    CONFERENCE_DIAL_OUT = "CONFERENCE_DIAL_OUT",
    CONFERENCE_RECORDING = "CONFERENCE_RECORDING",
    MSO365_CALENDAR_PRESENCE = "MSO365_CALENDAR_PRESENCE",
    MSO365_DIRECTORY_PROVISIONING = "MSO365_DIRECTORY_PROVISIONING",
    MSO365_DIRECTORY_SEARCH = "MSO365_DIRECTORY_SEARCH",
    MSO365_CONTACT_SEARCH = "MSO365_CONTACT_SEARCH",
    MS_OUTLOOK_PLUGIN = "MS_OUTLOOK_PLUGIN",
    MS_SKYPE_PLUGIN = "MS_SKYPE_PLUGIN",
    FILE_SHARING_QUOTA_GB = "FILE_SHARING_QUOTA_GB",
    GOOGLE_CALENDAR_PRESENCE = "GOOGLE_CALENDAR_PRESENCE",
    WEBRTC_P2P_RECORDING = "WEBRTC_P2P_RECORDING",
    BUBBLE_PROMOTE_MEMBER = "BUBBLE_PROMOTE_MEMBER",
    BUBBLE_GUESTS_ALLOWED = "BUBBLE_GUESTS_ALLOWED",
    BUBBLE_ACTIVE_SPEAKER = "BUBBLE_ACTIVE_SPEAKER",
    TELEPHONY_WEBRTC_GATEWAY = "TELEPHONY_WEBRTC_GATEWAY",
    TELEPHONY_WEBRTC_PSTN_CALLING = "TELEPHONY_WEBRTC_PSTN_CALLING",
    ANALYTICS_DASHBOARD_EC = "ANALYTICS_DASHBOARD_EC",
    ANALYTICS_DASHBOARD_BP = "ANALYTICS_DASHBOARD_BP",
    TELEPHONY_CALL_SUBJECT = "CALL_SUBJECT",
    CHANNEL_CREATE = "CHANNEL_CREATE",
    CHANNEL_CREATE_ADMIN_ROLE_BYPASS = "CHANNEL_CREATE_ADMIN_ROLE_BYPASS",
    CHANNEL_ACTIVATED = "CHANNEL_ACTIVATED",
    MANAGE_ANDROID_TV = "MANAGE_ANDROID_TV",
    USE_ANDROID_TV = "USE_ANDROID_TV",
    LDAP_DIRECTORY_SYNC = "LDAP_DIRECTORY_SYNC",
    LDAP_CONTACT_SYNC = "LDAP_CONTACT_SYNC",
    MASSPRO_USER_PROVISIONING_CSV = "MASSPRO_USER_PROVISIONING_CSV",
    SEARCH_BY_TAGS = "SEARCH_BY_TAGS",
    TELEPHONY_3DPARTY_ASSOC = "TELEPHONY_3DPARTY_ASSOC",
    WEBCLIENT_UI_2_0 = "WEBCLIENT_UI_2_0",
    WEBRTC_UNIFIED_PLAN = "WEBRTC_UNIFIED_PLAN",
    WEBRTC_CONFERENCE_SIMULCAST = "WEBRTC_CONFERENCE_SIMULCAST",
    USE_CLOUD_PBX = "USE_CLOUD_PBX",
    USE_OXO_MANAGED_PBX = "USE_OXO_MANAGED_PBX",
    SOFTPHONE_MODE_ONLY = "SOFTPHONE_MODE_ONLY",
    GIVE_REQUEST_REMOTE_CONTROL = "GIVE_REQUEST_REMOTE_CONTROL",
    BUBBLE_MAX_LOAD_STARTUP = "BUBBLE_MAX_LOAD_STARTUP",
    BUBBLE_COUNT = "BUBBLE_COUNT",
    BUBBLE_MEETING_SCHEDULER = "BUBBLE_MEETING_SCHEDULER",
    BUBBLE_TALKING_TIME = "BUBBLE_TALKING_TIME",
    APP_PERMISSIONS = "APP_PERMISSIONS",
    FREE_UI_CUSTOMIZATION = "FREE_UI_CUSTOMIZATION",
    PREMIUM_UI_CUSTOMIZATION = "PREMIUM_UI_CUSTOMIZATION",
    TELEPHONY_MAKE_CALL_CTI_APP = "TELEPHONY_MAKE_CALL_CTI_APP",
    CLOUD_PBX_WELCOME = "CLOUD_PBX_WELCOME",
    BUBBLE_TAG_COUNT = "BUBBLE_TAG_COUNT",
    TELEPHONY_CCD_AGENT = "TELEPHONY_CCD_AGENT",
    ALERT_NOTIFICATIONS_ALLOWED = "ALERT_NOTIFICATIONS_ALLOWED",
    BUBBLE_FOLDER_COUNT = "BUBBLE_FOLDER_COUNT",
    BUBBLE_POP_OUT_VIDEO_SHARING = "BUBBLE_POP_OUT_VIDEO_SHARING",
    ACCESSIBILITY_KEYBOARD_SHORTCUTS = "ACCESSIBILITY_KEYBOARD_SHORTCUTS",
    WEBRTC_ADD_PARTICIPANT = "WEBRTC_ADD_PARTICIPANT",
    WEBINAR_ACCESS = "WEBINAR_ACCESS",
    WEBINAR_MAX_ORGANIZERS = "WEBINAR_MAX_ORGANIZERS",
    WEBINAR_MAX_PARTICIPANTS = "WEBINAR_MAX_PARTICIPANTS",
    BLURRING_UI_2_0 = "BLURRING_UI_2_0",
    TELEPHONY_MAX_KEYS = "TELEPHONY_MAX_KEYS",
    TELEPHONY_MAX_SPEED_DIALING_KEYS = "TELEPHONY_MAX_SPEED_DIALING_KEYS",
    TELEPHONY_MAX_FEATURE_CODE_KEYS = "TELEPHONY_MAX_FEATURE_CODE_KEYS",
    TELEPHONY_MAX_SUPERVISION_KEYS = "TELEPHONY_MAX_SUPERVISION_KEYS",
    CONNECTIVITY_ALL_USER = "CONNECTIVITY_ALL_USER",
    WEBRTC_BLIND_TRANSFER_CALL = "WEBRTC_BLIND_TRANSFER_CALL",
    TELEPHONY_ADD_PARTICIPANT = "TELEPHONY_ADD_PARTICIPANT",
    TELEPHONY_BASIC_ATTENDANT_CONSOLE = "TELEPHONY_BASIC_ATTENDANT_CONSOLE",
    TELEPHONY_HYBRID_ATTENDANT_CONSOLE = "TELEPHONY_HYBRID_ATTENDANT_CONSOLE",
    MIX_WEBRTC_PSTN_CALLS = "MIX_WEBRTC_PSTN_CALLS",
    CLOUD_PBX_PERSONAL_ROUTINES = "CLOUD_PBX_PERSONAL_ROUTINES",
    TELEPHONY_MULTI_WEBRTC_GATEWAY = "TELEPHONY_MULTI_WEBRTC_GATEWAY",
    WEBRTC_GRID49 = "WEBRTC_GRID49",
    WEBRTC_CONFERENCE_V2_MODEL = "WEBRTC_CONFERENCE_V2_MODEL",
    TELEPHONY_OXO_MULTICALL = "TELEPHONY_OXO_MULTICALL",
    WEBRTC_MODULATE_VIDEO_QUALITY = "WEBRTC_MODULATE_VIDEO_QUALITY",
    ADMIN_ALARMS = "ADMIN_ALARMS",
    FLEXIBLE_PANEL = "FLEXIBLE_PANEL",
    BUBBLE_PSTN_DIALIN = "BUBBLE_PSTN_DIALIN",
    CONFERENCE_RECORDING_MAX_TIMER = "CONFERENCE_RECORDING_MAX_TIMER",
    PERSONAL_DIRECTORY = "PERSONAL_DIRECTORY",
    MSO365_TEAMS_PRESENCE = "MSO365_TEAMS_PRESENCE",
    ELEARNING_TRAINING = "ELEARNING_TRAINING",
    REPORT_A_PROBLEM = "REPORT_A_PROBLEM",
    WEBRTC_MANAGE_TWO_CALLS = "WEBRTC_MANAGE_TWO_CALLS",
    SUPERVISION_GROUP_MAX_NUMBER = "SUPERVISION_GROUP_MAX_NUMBER",
    SUPERVISION_GROUP_MAX_USERS = "SUPERVISION_GROUP_MAX_USERS",
    SUPERVISION_GROUP_SUPERVISOR_ALLOWED = "SUPERVISION_GROUP_SUPERVISOR_ALLOWED",
    SUPERVISION_GROUP_IN_OUT_ALLOWED = "SUPERVISION_GROUP_IN_OUT_ALLOWED",
    SUPERVISION_GROUP_SHOW_CONSOLE = "SUPERVISION_GROUP_SHOW_CONSOLE",
    TELEPHONY_CALL_POPOUT = "TELEPHONY_CALL_POPOUT",
    TELEPHONY_OXE_EMERGENCY = "TELEPHONY_OXE_EMERGENCY",
    MESSAGE_BOOKMARK = "MESSAGE_BOOKMARK",
    CLOUD_PBX_CALL_QUEUE_MAX_USERS = "CLOUD_PBX_CALL_QUEUE_MAX_USERS",
    CLOUD_PBX_MANAGER_ASSISTANT = "CLOUD_PBX_MANAGER_ASSISTANT",
    TELEPHONY_JOIN_BUBBLE = "TELEPHONY_JOIN_BUBBLE",
    TO_DO_LIST_MAX_ITEMS = "TO_DO_LIST_MAX_ITEMS",
    RED_ACCESS = "RED_ACCESS",
    COMPANY_DIRECTORY_INTERNAL_NUM = "COMPANY_DIRECTORY_INTERNAL_NUM",
    COMPANY_DIRECTORY_SHORTCODE = "COMPANY_DIRECTORY_SHORTCODE",
    TELEPHONY_SOFTPHONE_NOT_ALLOWED = "TELEPHONY_SOFTPHONE_NOT_ALLOWED",
    TELEPHONY_OXE_OVERFLOW = "TELEPHONY_OXE_OVERFLOW",
    CAPABILITY_OXE_OVERFLOW = "CAPABILITY_OXE_OVERFLOW",
    FILE_SHARING_EXTERNAL_OWNCLOUD = "FILE_SHARING_EXTERNAL_OWNCLOUD",
    AUDIO_NOISE_REDUCTION = "AUDIO_NOISE_REDUCTION",
    MIX_WEBRTC_PSTN_CALLS_FOR_PBX = "MIX_WEBRTC_PSTN_CALLS_FOR_PBX",
    WEBRTC_CALL_SHIFT = "WEBRTC_CALL_SHIFT",
    TELEPHONY_OXE_SECRET = "TELEPHONY_OXE_SECRET",
    TELEPHONY_SOFTPHONE_V3 = "TELEPHONY_SOFTPHONE_V3",
    TELEPHONY_SOFTPHONE_V3_UC = "TELEPHONY_SOFTPHONE_V3_UC",
    CLOUD_PBX_CALL_QUEUE_RECORDING = "CLOUD_PBX_CALL_QUEUE_RECORDING",
    OPEN_XCHANGE_CALENDAR_PRESENCE = "OPEN_XCHANGE_CALENDAR_PRESENCE",
    HYBRID_MANAGER_ASSISTANT = "HYBRID_MANAGER_ASSISTANT",
    BLUE_GREEN_WEB = "BLUE_GREEN_WEB",
    BUBBLE_POLLING = "BUBBLE_POLLING",
    RAISE_HAND_CONFERENCE = "RAISE_HAND_CONFERENCE",
    PROMOTE_ALL = "PROMOTE_ALL",
    TELEPHONY_MAX_CALL = "TELEPHONY_MAX_CALL",
    DESKTOP_EXTEND_BUTTON = "DESKTOP_EXTEND_BUTTON",
    CALL_DURING_BUBBLE = "CALL_DURING_BUBBLE",
    CONFERENCE_ATTENDANCE = "CONFERENCE_ATTENDANCE",
    PIN_MESSAGES = "PIN_MESSAGES",
    PINS_ITEMS_COUNT_PER_CONVERSATION = "PINS_ITEMS_COUNT_PER_CONVERSATION",
    TELEPHONY_CALL_BUSY = "TELEPHONY_CALL_BUSY",
    LOWER_ALL_HANDS = "LOWER_ALL_HANDS",
    CLOUD_PBX_DECT_ZERO_TOUCH = "CLOUD_PBX_DECT_ZERO_TOUCH",
    CLOUD_PBX_PHONES_GETLOGS = "CLOUD_PBX_PHONES_GETLOGS",
    SECURITY_PASSWORDLESS = "SECURITY_PASSWORDLESS",
    CLOUD_PBX_PHONES_GROUP_WITHDRAW = "CLOUD_PBX_PHONES_GROUP_WITHDRAW",
    BUBBLE_WAITING_ROOM = "BUBBLE_WAITING_ROOM",
    BLURRING_UI_3_0 = "BLURRING_UI_3_0",
    MASK_COMPANY_SEARCH = "MASK_COMPANY_SEARCH",
    CLEAR_CHAT = "CLEAR_CHAT",
    TELEPHONY_OXE_EMERGENCY_SITE = "TELEPHONY_OXE_EMERGENCY_SITE",
    TELEPHONY_CCD_AGENT_PROFILE = "TELEPHONY_CCD_AGENT_PROFILE",
    TELEPHONY_HYBRID_SOFTPHONE_CALL_SHIFT = "TELEPHONY_HYBRID_SOFTPHONE_CALL_SHIFT"
}
export declare class ProfileService extends Service {
    FeaturesEnum: Record<string, string>;
    rxSubject: Subject<any>;
    telsoftPhoneNotAllowed: BehaviorSubject<boolean>;
    /**
     * @public
     * This RB event is send when the features list of the logged user has changed.
     */
    static PROFILE_FEATURES_UPDATE: string;
    static PROFILE_TELEPHONY_SOFTPHONE_NOT_ALLOWED: string;
    private started;
    private features;
    private profiles;
    private mainOffers;
    private thirdPartyApps;
    private sdkApiKeys;
    private profileEventHandler;
    private timer;
    private contactService;
    private logger;
    private authService;
    private xmppService;
    static getInstance(): ProfileService;
    static build(): ProfileService;
    private constructor();
    start(): Promise<void>;
    stop(): Promise<void>;
    reconnect(): void;
    restart(): void;
    subscribe(handler: any): Subscription;
    private attachHandlers;
    private detachHandlers;
    private onManagementMessageReceived;
    private onUserUpdateNeeded;
    private getServerProfile;
    private getServerProfiles;
    private getServerProfilesFeatures;
    isFeatureEnabled(featureUniqueRef: string, features?: any): boolean;
    getFeatureLimitMax(featureUniqueRef: string, features?: any): number;
    getFeatureLimitMin(featureUniqueRef: string, features?: any): number;
    getMyProfiles(): any[];
    getMyProfileFeatures(): any;
    getThirdPartyApps(force?: boolean): Promise<any>;
    revokeThirdPartyAccess(tokenId: string): Promise<any>;
    getProfilesByName(name: string): any;
    /**
    * This API allow a user to get all his API_KEYs, or an administrator to get all API_KEYs of a user that he's responsible
    */
    getAllSdkApiKeys(): Promise<SdkApiKey[]>;
    /**
    * Create a new SDK Api Key
    * @param description - the description of the key
    * @param expirationDate - the date of the expiration or null for never expires
    * Returns the list of the all SDK Api Keys
    */
    createSdkApiKey(description: string, expirationDate: Date | null): Promise<SdkApiKey>;
    /**
    * Deletes a SDK Api Key
    * @param sdkApiKey - the key to delete
    * Returns the list of the remaining SDK Api Keys
    */
    deleteSdkApiKey(sdkApiKey: SdkApiKey): Promise<SdkApiKey[]>;
}
//# sourceMappingURL=profile.service.d.ts.map