import { Service } from '../../services/service';
import { DirectoryInternalSearchResults, DirectorySearchOptions } from '../../services/core/directorySearch.service';
import { Contact } from '../../models/contact.model';
export declare const PHONEBOOK_SVC = "PhonebookService";
export declare class PhonebookService extends Service {
    private authService;
    private contactService;
    private profileService;
    private errorHelperService;
    private logger;
    protected constructor();
    static getInstance(): PhonebookService;
    static build(): PhonebookService;
    /**
     * This API allows users to search phonebook users by specifying a pattern
     * (API request to {@link https://api.openrainbow.org/search/#api-phonebook-searchInPhonebook Rainbow search portal - phonebook - phonebook - Search in phonebook})
     * @public
     * @description
     * Search contacts in the PBX phonebook the user is connected to by using a specified pattern to filter items.
     * This search is only available if the user has the feature TELEPHONY_PHONE_BOOK in its profile.
     * If specified, the option 'extendedMode' is ignored as the multi-criteria search (associated with feature SEARCH_BY_TAGS) is not available on Phonebook.
     * @param {string} searchPattern Pattern to search
     * @param {DirectorySearchOptions} [options] Search options {@link DirectorySearchOptions}
     * @returns {Promise<DirectoryInternalSearchResults[]>} Resolves with an array of results and the total number of directory items matching the criteria.
     * {@link DirectoryInternalSearchResults}
     * @memberof PhonebookService
     */
    searchPBXUsers(searchPattern: string, options?: DirectorySearchOptions): Promise<DirectoryInternalSearchResults>;
    /**
     * This API allows users to search phonebook users by specifying a phone number
     * (API request to {@link https://api.openrainbow.org/search/#api-phonebook-searchInPhonebook Rainbow search portal - phonebook - phonebook - Search in phonebook})
     * @public
     * @description
     * Search contacts in the PBX phonebook the user is connected to by using a specified pattern to filter items on phone number.
     * This search is only available if the user has the feature TELEPHONY_PHONE_BOOK in its profile.
     * @param {string} searchPattern Phone number to search
     * @returns {Promise<Contact[]>} Resolves with an array of {@link Contact} results and
     * the total number of directory items matching the criteria.
     * @memberof PhonebookService
     */
    searchByNumber(searchPattern: string): Promise<Contact | null>;
}
//# sourceMappingURL=phonebook.service.d.ts.map