import { Service } from '../../services/service';
export interface ISpeechEnhancementService {
    startProcessStream(id: string, stream: MediaStream, serviceName?: string): Promise<MediaStream>;
    stopProcessStream(id: string, serviceName?: string): Promise<void>;
}
export declare const SPEECH_ENH_SVC = "SpeechEnhancementService";
export declare class SpeechEnhancementService extends Service implements ISpeechEnhancementService {
    static getInstance(): SpeechEnhancementService;
    static build(): SpeechEnhancementService;
    private constructor();
    private logger;
    private settingsService;
    private mainService;
    private profileService;
    private webConferenceService;
    private stream;
    private context;
    private streamDestination;
    private speechEnhancementNode;
    private preGainNode;
    private postGainNode;
    private filterNode;
    private workletActivated;
    private source;
    private originalTrack;
    private activeSpeechEnhancements;
    /**
     * @function startProcessStream
     * @instance
     * @public
     * @async
     * @description Start the effect of speech enhancement
     * @param {string} id the ID that will be releated to the speech enchacement object containing the streams
     * @param {MediaStream} stream The MediaStream  that we will process
     * @param {string} serviceName The name of service that calls the method (optional, for debug purpose)
     * @returns {Promise<MediaStream>} the new media stream
     */
    startProcessStream(id: string, stream: MediaStream, serviceName?: string): Promise<MediaStream>;
    /**
     * @function stopProcessStream
     * @instance
     * @public
     * @async
     * @description Stop and destroy all tracks
     * @param {string} id the ID of the speech enchacement object containing the streams to be stopped
     * @param {string} serviceName The name of service that calls the method (optional, for debug purpose)
     */
    stopProcessStream(id: string, serviceName?: string): Promise<void>;
    /****************************************************************************/
    /** SERVICE LIFECYCLE                                                      */
    /****************************************************************************/
    /**
     * @function start
     * @private
     * @async
     * @description This async method has to be call to start the speech enhancement Service
     * @returns {Promise<void>} a promise that resolve when speech enhancement service is started
     */
    start(): Promise<void>;
    /**
     * @function stop
     * @private
     * @async
     * @description This async method has to be call to stop the speech enhancement Service
     * @returns {Promise<void>} a promise that resolve when speech enhancement service is stopped
     */
    stop(): Promise<void>;
    /**
     * @function reconnect
     * @private
     * @async
     * @description This async method has to be call to reconnect the speech enhancement Service
     * @returns {Promise<void>} a promise that resolve when speech enhancement service is reconnected
     */
    reconnect(): Promise<void>;
}
//# sourceMappingURL=speech-enhancement.service.d.ts.map