/**
 * Live Transcription service
 * @module LiveTranscription
 */
import { Service } from '../../services/service';
import { Subscription } from 'rxjs';
import { Bubble, LiveTranscription, RBEvent } from '../../index';
/** @internal */
export declare const LIVE_TRANSCRIPTION_SVC = "LiveTranscriptionService";
/**
 * TranscriptionService events list
 * @eventProperty
 */
export declare enum LiveTranscriptionServiceEvents {
    /**
     * @eventProperty
     * This RBEvent is send when a liveTranscription is available
     */
    ON_LIVE_TRANSCRIPTION_AVAILABLE = "ON_LIVE_TRANSCRIPTION_AVAILABLE",
    /**
     * @eventProperty
     * This RBEvent is send when a liveTranscription is stopped
     */
    ON_LIVE_TRANSCRIPTION_STOPPED = "ON_LIVE_TRANSCRIPTION_STOPPED"
}
export interface LiveTranscriptionService {
    /**
     * Subscribe to transcription service events
     * @param handler - The handler function that will be called on events
     * @param eventNames - The events to subscribe to
     */
    subscribe(handler: (event: RBEvent<LiveTranscriptionServiceEvents>) => any, eventNames?: LiveTranscriptionServiceEvents | LiveTranscriptionServiceEvents[]): Subscription;
    /**
     * Returns existing live transcription for a conversation
     * @param source - the sourse
     */
    getLiveTranscriptions(source: Bubble): LiveTranscription[];
    /**
     * This methods start speechToText transcription portal
     * @param source - the conversation bubble
     */
    startTranscription(source: Bubble): Promise<void>;
    /**
     * This methods stop speechToText transcription portal
     * @param source - the conversation bubble
     */
    stopTranscription(source: Bubble): Promise<void>;
    /**
     * This methods send a message on transcription datachannel (DEBUG)
     * @param source - the conversation bubble
     * @param message - the message to send via transcription message
     * @internal
     */
    sendTranscriptionMessage(source: Bubble, message: string): Promise<void>;
}
/**
 * @internal
 */
export declare class LiveTranscriptionServiceRB extends Service implements LiveTranscriptionService {
    private logger;
    private dataChannelService;
    private authService;
    private settingsService;
    private errorHelperService;
    private xmppService;
    private subscriptions;
    private eventsSubject;
    private transcriptions;
    private conferenceEventListener;
    private promiseQueue;
    static getInstance(): LiveTranscriptionServiceRB;
    static build(): LiveTranscriptionServiceRB;
    private constructor();
    start(): Promise<void>;
    stop(): Promise<void>;
    reconnect(): Promise<void>;
    private attachEventListeners;
    subscribe(handler: (event: RBEvent<LiveTranscriptionServiceEvents>) => any, eventNames?: LiveTranscriptionServiceEvents | LiveTranscriptionServiceEvents[]): Subscription;
    sendEvent(name: LiveTranscriptionServiceEvents, data?: any): void;
    startTranscription(source: Bubble): Promise<void>;
    stopTranscription(source: Bubble): Promise<void>;
    sendTranscriptionMessage(source: Bubble, message: string): Promise<void>;
    getLiveTranscriptions(source: Bubble): LiveTranscription[];
    private onConferenceInfo;
}
//# sourceMappingURL=liveTranscription.service.d.ts.map