import { RBEvent, Service } from "../../index";
import { Subscription } from "rxjs";
/** @internal */
export declare const USER_SVC = "UserService";
/**
 * Users service events
 * Can listen to it via `UserService.subscribe()` API.
 * @eventProperty
 */
export declare enum UserServiceEvents {
    /**
    * @eventProperty
    */
    ON_USER_CHANGED = "ON_USER_CHANGED"
}
/**
 * User Service interface
 */
export interface UserService {
    /**
     * Subscribe to updates from the user service, all events are of RBEvent<UserServiceEvents>
     * @param callback - The callback function that will be called when events are received
     * @param eventNames - Array of event to listen
     * @returns Returns RxJS Subscription
     */
    subscribe(callback: (event: RBEvent<UserServiceEvents>) => any, eventNames?: UserServiceEvents | UserServiceEvents[]): Subscription;
}
/**
 * User Service implementation
 * @internal
 */
export declare class UserServiceRB extends Service implements UserService {
    private rxSubject;
    private logger;
    /**
      * Returns the Favorite service singleton
      */
    static getInstance(): UserServiceRB;
    static build(): UserServiceRB;
    private constructor();
    subscribe(handler: (event: RBEvent<UserServiceEvents>) => any, eventNames?: UserServiceEvents | UserServiceEvents[]): Subscription;
    /**
     * User service events send method
     * Can listen to it via UserService.subscribe() API
     * @param name - the name of the event
     * @param data - the data to be send (an object)
     */
    sendEvent(name: UserServiceEvents, data?: any): void;
}
//# sourceMappingURL=user.service.d.ts.map