import { BlendMode, Webgl2Pipeline } from './webgl2Pipeline';
export declare class ImageStage {
    private vbWebgl2;
    private vbHelper;
    private vertexShaderImage;
    private fragmentShaderImage;
    private program;
    private backgroundTexture;
    private outputRatio;
    private backgroundLocation;
    private backgroundScaleLocation;
    private backgroundOffsetLocation;
    private coverageLocation;
    private lightWrappingLocation;
    private blendModeLocation;
    private gl;
    private video;
    private options;
    /**
     * @function create
     * @static
     * @public
     * @param {Options} options The options (type and url) of the image or the video
     * @param {Webgl2Pipeline} vbWebgl2 The instance of the webgl2 class
     * @returns {ImageStage | null} Initialization of the class
     */
    static create(options: any, vbWebgl2: Webgl2Pipeline): Promise<ImageStage | null>;
    private constructor();
    /**
     * @function render
     * @public
     * @description Assembles the mask with the person's video stream and the virtual background image
     */
    render(): void;
    /**
     * @function updateCoverage
     * @public
     * @param {[number, number]} coverage
     */
    updateCoverage(coverage: [number, number]): void;
    /**
     * @function updateLightWrapping
     * @public
     * @param {number} lightWrapping The lightWrapping parameter
     * @description Light wrapping is a compositing technique designed to blend keyed out green screen footage with a background plate
     */
    updateLightWrapping(lightWrapping: number): void;
    /**
     * @function updateBlendMode
     * @public
     * @param {BlendMode} blendMode The mode that will apply
     * @description determines how the two layers will be blended together.
     */
    updateBlendMode(blendMode: BlendMode): void;
    /**
     * @function cleanUp
     * @public
     * @description removes the different components used to make the assembly with the image
     */
    cleanUp(): void;
    /**
     * @function updateBackgroundImage
     * @public
     * @param {any} background An HTMLLImageElement or HTMLVideoElement that contains the virtual background that will be placed behind the person
     * @description Resize the virtual background to the right size
     */
    updateBackgroundImage(background: any): void;
}
//# sourceMappingURL=imageStage.d.ts.map