import { Webgl2Pipeline } from './webgl2Pipeline';
export declare class ResizingStage {
    private vbWebgl2;
    private vbHelper;
    private videoOutputPixels;
    private videoFrameBuffer;
    private program;
    private fragmentShader;
    private videoTexture;
    private gl;
    private segmentationMaskWidth;
    private segmentationMaskHeight;
    /**
     * @function create
     * @static
     * @public
     * @param {Webgl2Pipeline} vbWebgl2 The instance of the webgl2 class
     * @returns {ResizingStage} Initialization of the class
     */
    static create(vbWebgl2: Webgl2Pipeline): ResizingStage;
    private constructor();
    /****************************************************************************/
    /** PUBLIC STUFF                                                           **/
    /****************************************************************************/
    /**
     * @function render
     * @async
     * @public
     * @description resizes each received image to a smaller size and writes the data to a buffer in tflite
     */
    render(): Promise<void>;
    /**
     * @function cleanUp
     * @public
     * @description removes the different components used to resize the mask
     */
    cleanUp(): void;
    /****************************************************************************/
    /** PRIVATE STUFF                                                          **/
    /****************************************************************************/
    /**
     * @function getBufferSubDataAsync
     * @async
     * @private
     * @param {WebGLBuffer} buffer The buffer containing the video data
     * @param {ArrayBufferView} dstBuffer The destination buffer, which will receive the video data
     * @description Requires the execution of all pending tasks before synchronizing the two processors and sending the data to a buffer
     */
    private getBufferSubDataAsync;
    /**
     * @function clientWaitAsync
     * @private
     * @param {WebGLSync} sync the WebGLSync object
     * @description synchronizes both processors (CPU and GPU)
     * @returns {number} Returns gl.CONDITION_SATISFIED if the synchronization was successful, and gl.WAIT_FAILED if there was an error
     */
    private clientWaitAsync;
}
//# sourceMappingURL=resizingStage.d.ts.map