export declare class WebglHelper {
    /**
     * @function create
     * @static
     * @public
     * @returns {WebglHelper} Initialization of the class
     */
    static create(): WebglHelper;
    private constructor();
    /**
     * @function initShader
     * @public
     * @param {WebGL2RenderingContext} gl the context of webgl2
     * @param {number} shaderType The type of Shader to compile (vertex or fragment shader)
     * @param {string} shaderSource The Shader to compile
     * @description Compile the shader
     * @returns {WebGLShader} Returns the compiled shader
     */
    initShader(gl: WebGL2RenderingContext, shaderType: number, shaderSource: string): WebGLShader;
    /**
     * @function initProgram
     * @public
     * @param {WebGL2RenderingContext} gl the context of webgl2
     * @param {WebGLShader} vertexShader The compiled vertex shader
     * @param {WebGLShader} fragmentShader The compiled fragment shader
     * @param {WebGLBuffer} positionBuffer the buffer containing the coordinates of the canvas
     * @param {WebGLBuffer} texCoordBuffer the buffer containing the coordinates of the canvas textures
     * @description Initiates the compiled program
     * @returns {WebGLProgram} The program correctly compiled and initialized
     */
    initProgram(gl: WebGL2RenderingContext, vertexShader: WebGLShader, fragmentShader: WebGLShader, positionBuffer: WebGLBuffer, texCoordBuffer: WebGLBuffer): WebGLProgram;
    /**
     * @function createProgram
     * @public
     * @param {WebGL2RenderingContext} gl the context of webgl2
     * @param {WebGLShader} vertexShader The compiled vertex shader
     * @param {WebGLShader} fragmentShader The compiled fragment shader
     * @description Compiles the given program with the vertex and fragment shader
     * @returns {WebGLProgram} Returns the compiled program
     */
    private createProgram;
    /**
     * @function createTexture
     * @public
     * @param {WebGL2RenderingContext} gl the context of webgl2
     * @param {number} internalFormat A GLenum specifying the texture store format
     * @param {number} width A GLsizei specifying the width of the texture
     * @param {number} height A GLsizei specifying the height of the texture
     * @param {number} minFilter Paremeter for the texture magnification filter
     * @param {number} magFilter Parameter for the texture minification filter
     * @description Create a texture according to the given parameters
     * @returns {WebGLTexture} Returns the created texture
     */
    createTexture(gl: WebGL2RenderingContext, internalFormat: number, width: number, height: number, minFilter?: number, magFilter?: number): WebGLTexture;
}
//# sourceMappingURL=webglHelper.d.ts.map